Crate rawgrep

Crate rawgrep 

Re-exports

pub use error::Error;
pub use stats::Stats;
pub use grep::RawGrepper;
pub use ctx::RawGrepCtx;
pub use tracing;
pub use crossbeam_channel;

Modules

apfs
binary
cache
cli
ctx
error
ext4
fragments
Fragment-Based Cache System
grep
ignore
matcher
ntfs
parser
path_buf
platform
Platform-specific abstractions for device operations
stats
tracy
util
worker

Macros

ceprint
ceprintln
cwrite
cwriteln
eprint_blue
eprint_cyan
eprint_green
eprint_red
eprintln_blue
eprintln_cyan
eprintln_green
eprintln_red
write_blue
write_cyan
write_green
write_red
writeln_blue
writeln_cyan
writeln_green
writeln_red

Structs

CursorHide
RawGrepConfig
Configuration for a single rawgrep search.

Constants

COLOR_BLUE
COLOR_CYAN
COLOR_GREEN
COLOR_RED
COLOR_RESET
CURSOR_HIDE
CURSOR_UNHIDE

Functions

copy_data
Helper used to indicate that we copy some amount of copiable data (bytes) into a newly allocated memory
run
Run a search with the given configuration and sink.
run_with_inspect
setup_signal_handler

Type Aliases

Result