Re-exports
pub use error::Error;pub use stats::Stats;pub use grep::RawGrepper;pub use ctx::RawGrepCtx;pub use tracing;pub use crossbeam_channel;
Modules
- apfs
- binary
- cache
- cli
- ctx
- error
- ext4
- fragments
- Fragment-Based Cache System
- grep
- ignore
- matcher
- ntfs
- parser
- path_
buf - platform
- Platform-specific abstractions for device operations
- stats
- tracy
- util
- worker
Macros
- ceprint
- ceprintln
- cwrite
- cwriteln
- eprint_
blue - eprint_
cyan - eprint_
green - eprint_
red - eprintln_
blue - eprintln_
cyan - eprintln_
green - eprintln_
red - write_
blue - write_
cyan - write_
green - write_
red - writeln_
blue - writeln_
cyan - writeln_
green - writeln_
red
Structs
- Cursor
Hide - RawGrep
Config - Configuration for a single rawgrep search.
Constants
Functions
- copy_
data - Helper used to indicate that we copy some amount of copiable data (bytes) into a newly allocated memory
- run
- Run a search with the given configuration and sink.
- run_
with_ inspect - setup_
signal_ handler